<?php

$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%d best incoming links: "] =
   "%d migliori link in entrata: ";
$locale["%d best outgoing links: "] =
   "%d migliori link in uscita: ";
$locale["%d most popular nearby: "] =
   "%d pi popolari: ";
$locale["%s Kb (%s bytes)"] =
   "%s Kb (%s byte)";
$locale["%s at %s"] =
   "%s a %s";
$locale["%s bytes"] =
   "%s byte";
$locale["%s days"] =
   "%s giorni";
$locale["%s not found"] =
   "%s non trovato";
$locale["%s of this page"] =
   "%s di questa pagina";
$locale["%s on %s:"] =
   "%s a %s:";
$locale["%s: %s"] =
   "%s: %s";
$locale["%s: file not found"] =
   "%s: archivio non trovato";
$locale["%s: not defined"] =
   "%s: non definito";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] =
   "(Copia le tue modifiche nella clipboard. Potete provare a modificare un'altra pagina o registra il vostro testo in un editor di testo.)";
$locale["(diff)"] =
   "(diff)";
$locale[", Memory: %s"] =
   ", RAM: %s";
$locale["- saved to database as version %d"] =
   "- salvata a base di dati a versione %d";
$locale["- version %d saved to database as version %d"] =
   "- versione %d salvata a base di dati a versione %d";
$locale["... copied to %s"] =
   "... copia di %s";
$locale["... not copied to %s"] =
   "... nonc opia di %s";
$locale["... not found"] =
   "... non trovato";
$locale["1 day"] =
   "1 giorno";
$locale["<no matches>"] =
   "<nessun risultati>";
$locale["<none>"] =
   "<nessun>";
$locale["<unknown>"] =
   "<sconosciuto>";
$locale["AddCategory"] =
   "InsertoCategoria";
$locale["AddPlugin"] =
   "InsertoPlugin";
$locale["Authenticated as %s"] =
   "Authenticata a %s";
$locale["Author"] =
   "Autore";
$locale["Calendar"] =
   "Calendario";
$locale["CalendarList"] =
   "ListaCalendario";
$locale["CalendarListPlugin"] =
   "CalendarioListPlugin";
$locale["CalendarPlugin"] =
   "CalendarioPlugin";
$locale["Cancel"] =
   "Annulla";
$locale["Cancel rating"] =
   "Annulla";
$locale["CategoryGroup"] =
   "CategoriaGruppo";
$locale["CategoryPage"] =
   "CategoriaPagina";
$locale["Columns: %s."] =
   "Caratteri: %s.";
$locale["Comment"] =
   "Commentario";
$locale["Content"] =
   "Indice";
$locale["Contents"] =
   "Indice";
$locale["Convert"] =
   "Convertito";
$locale["Couldn't connect to %s"] =
   "Non riesco a stabilire una connessione col database: %s";
$locale["Create: %s"] =
   "Salvata: %s";
$locale["Deleted"] =
   "Rimossa";
$locale["Describe %s here."] =
   "Descrivi %s qui.";
$locale["Diff"] =
   "Diff";
$locale["Diff: %s"] =
   "Differenza di: %s";
$locale["Edit"] =
   "Modifica";
$locale["Edit %s"] =
   "Modifica %s";
$locale["Edit: %s"] =
   "Modifica: %s";
$locale["EditText"] =
   "ModificaIlTesto";
$locale["Edited by: %s"] =
   "Modifica: %s";
$locale["Fatal PhpWiki Error"] =
   "Errore Fatale Di PhpWiki";
$locale["FindPage"] =
   "TrovaPagina";
$locale["First"] =
   "Prima";
$locale["Full text search results for '%s'"] =
   "Risultati della ricerca su tutto il testo per '%s'";
$locale["FullTextSearch"] =
   "RicercaDelTesto";
$locale["Go"] =
   "Vai";
$locale["GoTo"] =
   "Vai";
$locale["GoodStyle"] =
   "BuonStile";
$locale["H"] =
   "A";
$locale["Height"] =
   "Altezza";
$locale["Home"] =
   "Principale";
$locale["HomePage"] =
   "PaginaPrincipale";
$locale["HomePageAlias"] =
   "PaginaPrincipaleAlias";
$locale["Include of '%s' failed."] =
   "Inserimento di '%s' fallito.";
$locale["IncludePage"] =
   "InserireLaPagina";
$locale["IncludePagePlugin"] =
   "InserireLaPaginaPlugin";
$locale["IncludePages"] =
   "InserirePaginas";
$locale["Included from %s"] =
   "Inserire dalla %s";
$locale["Included from %s:"] =
   "Inserire dalla %s:";
$locale["Insert"] =
   "Inserto";
$locale["Insert Categories (double-click)"] =
   "Inserto Categorias (doppio-scatto)";
$locale["Insert PageLink (double-click)"] =
   "Inserto Pagina (doppio-scatto)";
$locale["Insert Plugin (double-click)"] =
   "Inserto Plugin (doppio-scatto)";
$locale["Last"] =
   "Ultima";
$locale["Last Author"] =
   "Ultimo Autore";
$locale["Last Modified"] =
   "Ultima Modifica";
$locale["Last Summary"] =
   "Ultimo Commenti";
$locale["Last edited %s"] =
   "Ultima modifica %s";
$locale["Last edited on %s"] =
   "Ultima modifica su %s";
$locale["LdapSearch"] =
   "LdapRicerca";
$locale["LiveSearch"] =
   "RicercaLive";
$locale["Lock"] =
   "Bloccata";
$locale["Lock Page"] =
   "Blocca la Pagina";
$locale["Locked"] =
   "Bloccata";
$locale["MIME file %s"] =
   "MIME archivio %s";
$locale["ModeratedPage"] =
   "PaginaModerata";
$locale["Modern"] =
   "Moderno";
$locale["Modified"] =
   "Modifica";
$locale["MostPopular"] =
   "PiPopolari";
$locale["Name"] =
   "Nome";
$locale["New page"] =
   "Nuova pagina";
$locale["Newer page:"] =
   "Nuova pagina:";
$locale["Next"] =
   "Seguente";
$locale["None"] =
   "Nessuno";
$locale["Note:"] =
   "Nota:";
$locale["Optimizing database"] =
   "Base di dati d'ottimizzazione";
$locale["Other version"] =
   "Mostra il versione corrente";
$locale["Owner: %s"] =
   "Owner: %s";
$locale["Page %s not found."] =
   "%s: pagina non trovato.";
$locale["Page Locked"] =
   "Pagina Bloccata";
$locale["Page Name"] =
   "Nome Della Pagina";
$locale["Page now locked."] =
   "Pagina bloccata.";
$locale["Page now unlocked."] =
   "Pagina sbloccata.";
$locale["Page removed %s"] =
   "Pagina rimosso %s";
$locale["PhpWikiAdministration/Remove"] =
   "AmministrazioneDiPhpWiki/Rimuovi";
$locale["Plugin %s disabled."] =
   "Plugin '%s' inabiliti.";
$locale["Plugin %s failed."] =
   "Plugin '%s' fallito.";
$locale["Plugin %s: undefined"] =
   "Plugin '%s': non definito";
$locale["PreferencesInfo"] =
   "PreferenzeInfo";
$locale["PrevNext"] =
   "Seguente";
$locale["Previous"] =
   "Precedente";
$locale["Previous Author"] =
   "Precedente Author";
$locale["Previous Revision"] =
   "Precedente";
$locale["Printer"] =
   "Stampante";
$locale["RecentChanges"] =
   "CambiamentiRecenti";
$locale["Remove"] =
   "Rimuovi";
$locale["Remove Page"] =
   "Rimuovi la Pagina";
$locale["Remove this page"] =
   "Rimuovi la pagina";
$locale["Removed page '%s' successfully."] =
   "La pagina '%s'  stata rimossa correttamente.";
$locale["Save"] =
   "Registra";
$locale["Saved: %s"] =
   "Salvata: %s";
$locale["Search"] =
   "Ricerca";
$locale["See %s tips for editing."] =
   "Vedere %s consigli per le modifiche.";
$locale["Select"] =
   "Prescelto";
$locale["Show minor edits for:"] =
   "Mostrare le modifiche secondarie per:";
$locale["Signed as %s"] =
   "Salvata a %s";
$locale["Size"] =
   "Dimensione";
$locale["Size:"] =
   "Dimensione:";
$locale["Someone has edited the page!"] =
   "Qualcuno ha modificato la pagina!";
$locale["Sorry for the inconvenience."] =
   "Scusa per l'inconveniente.";
$locale["Sort by %s"] =
   "Sort di %s";
$locale["String \"%s\" not found."] =
   "\"%s\" non trovato.";
$locale["Summary"] =
   "Commenti";
$locale["Synopsis"] =
   "Sinossi";
$locale["TextFormattingRules"] =
   "RegoleDiFormattazioneDelTesto";
$locale["Thank you for editing %s."] =
   "Grazie per le modifiche! %s.";
$locale["Thanks for adding this translation!"] =
   "Grazie per la translatione!";
$locale["The %d most popular pages of this wiki:"] =
   "Le %d pagine pi popolari di questo wiki sono:";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Questa pagina  stata bloccata dall'amministratore e non pu essere modificata.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "Questa pagina  stata bloccata dall'amministratore in modo da i vostri cambiamenti non possono essere salvati.";
$locale["Time Zone"] =
   "Fuso Orario";
$locale["Title Search"] =
   "La ricerca su tutto il testo";
$locale["Title search results for '%s'"] =
   "Risultati della ricerca su tutto il testo per '%s'";
$locale["TitleSearch"] =
   "RicercaSuTutto";
$locale["Today"] =
   "Oggi";
$locale["Transcluded from %s"] =
   "Inserire dalla %s";
$locale["Unlock"] =
   "Sblocca";
$locale["Unlock Page"] =
   "Sblocca la Pagina";
$locale["UserPreferences"] =
   "Preferenze";
$locale["Version"] =
   "Versione";
$locale["Version %d"] =
   "Versione %d";
$locale["Version %s"] =
   "Versione %s";
$locale["Version %s, saved %s"] =
   "Versione %s, salvata %s";
$locale["Version %s, saved on %s"] =
   "Versione %s, salvata su %s";
$locale["Versions are identical"] =
   "Le versioni sono identiche";
$locale["View the current version"] =
   "Mostra il versione corrente";
$locale["W"] =
   "L";
$locale["Warning!"] =
   "Avvertimento!";
$locale["Warning:"] =
   "Avvertimento:";
$locale["Width"] =
   "Larghezza";
$locale["Wiki Name"] =
   "Wiki Nome";
$locale["Yes"] =
   "Si";
$locale["Your careful attention to detail is much appreciated."] =
   "La tua cura verso il dettaglio  molto apprezzata.";
$locale["Your home page is locked so your preferences cannot not be saved."] =
   "Questa pagina  stata bloccata dall'amministratore in modo da i vostri cambiamenti non possono essere salvati.";
$locale["Your version"] =
   "versione corrente";
$locale["by %s"] =
   "di %s";
$locale["current version"] =
   "versione corrente";
$locale["days"] =
   "giorni";
$locale["diff"] =
   "diff";
$locale["from %s"] =
   "dalla %s";
$locale["locked"] =
   "bloccata";
$locale["name"] =
   "Nome";
$locale["plain file %s"] =
   "archivio del testo %s";
$locale["saved as "] =
   "salvata a ";
$locale["saved as %s"] =
   "salvata a %s";
$locale["today"] =
   "oggi";
$locale["version %d"] =
   "versione %d";
$locale["version %s"] =
   "versione %s";
$locale["version <em>%s</em>"] =
   "versione <em>%s</em>";
$locale["yesterday"] =
   "ieri";

?>
